CqrsPattern

Struct CqrsPattern 

pub struct CqrsPattern<A>(/* private fields */);
Public, zero-sized handle to the CQRS pattern. Use CqrsPattern::builder to start configuring an instance.

Implementations

Source

impl<A> CqrsPattern<A>
where A: AggregateRoot, A::Command: Command<AggregateId = <A as AggregateRoot>::Id>, A::Event: DomainEvent,

pub fn builder<J: Journal>(journal: Arc<J>) -> CqrsBuilder<A, J>

Start a fluent builder for a CQRS instance backed by journal.

The journal type J flows into the rest of the builder, so the rest of the configuration is type-checked. Call CqrsBuilder::factory, CqrsBuilder::read_journal (if you want readers), and CqrsBuilder::build to obtain a CqrsTopology.